.. _spkg_chardet:

chardet: Universal encoding detector for Python 3
=================================================

Description
-----------

Universal encoding detector for Python 3

License
-------

LGPL

Upstream Contact
----------------

https://pypi.org/project/chardet/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    5.2.0

version_requirements.txt::

    chardet

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install chardet

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i chardet

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-chardet


If the system package is installed, ``./configure`` will check if it can be used.
